API Reference
=============

.. module:: pydyf

.. autoclass:: Object
   :members:

.. autoclass:: Dictionary

.. autoclass:: Stream
   :members:

.. autoclass:: String

.. autoclass:: Array

.. autoclass:: PDF
   :members:
